@@ -212,9 +212,6 @@ class FactTestCase(unittest.TestCase):
         for columnName, columnType in self.__fieldInfo:
             if TestUtilities.check_dimension_key_name_and_type(columnName, columnType):
 
-                if not tableDf:
-                    tableDf = self.__spark.get_table_or_view(self.__databaseName, self.__tableName)
-
                 uniqueValues = self.__spark.get_distinct_column_values_from_df(self.__tableDataFrame, columnName)
 
                 for val in uniqueValues:
@@ -256,7 +253,7 @@ class FactTestCase(unittest.TestCase):
             dimensionFieldInfo[(dimensionDatabaseName, dimensionTableName)] = self.__spark.get_field_info_table_or_view(dimensionDatabaseName, dimensionTableName)
 
         for key in dimensionKeys:
-            for dimInfo, schema in dimensionInfo.items():
+            for dimInfo, schema in dimensionFieldInfo.items():
                 
                 dimensionColumns = {column[0] for column in schema}
                 
@@ -304,7 +301,7 @@ class FactTestCase(unittest.TestCase):
         for dimensionInfo in self.__linkedDimensionTables:
             dimensionDatabaseName = dimensionInfo[0]
             dimensionTableName = dimensionInfo[1]
-            dimensionFieldInfo[dimensionTableName] = self.__spark.get_field_info(dimensionDatabaseName, dimensionTableName)
+            dimensionFieldInfo[dimensionTableName] = self.__spark.get_field_info_table_or_view(dimensionDatabaseName, dimensionTableName)
 
         keyColumns = [column[0] for column in self.__fieldInfo if TestUtilities.check_dimension_key_name_and_type(column[0], column[1])]
         
